Learn R Programming

KSEAapp (version 0.99.0)

KSEA.Scores: The KSEA App Analysis (KSEA Kinase Scores Only)

Description

Takes a formatted phoshoproteomics data input and returns just the KSEA kinase scores and statistics

Usage

KSEA.Scores(KSData, PX, NetworKIN, NetworKIN.cutoff)

Arguments

KSData
the Kinase-Substrate dataset uploaded from the file prefaced with "PSP&NetworKIN_" available from github.com/casecpb/KSEA/
PX
the experimental data file formatted as described in the KSEA.Complete() documentation
NetworKIN
a binary input of TRUE or FALSE, indicating whether or not to include NetworKIN predictions; NetworKIN = TRUE means inclusion of NetworKIN predictions
NetworKIN.cutoff
a numeric value between 1 and infinity setting the minimum NetworKIN score (can be left out if NetworKIN = FALSE)

Value

creates a new data frame in R with all the KSEA kinase scores, along with each one's statistical assessment

References

Casado et al. (2013) Sci Signal. 6(268):rs6

Hornbeck et al. (2015) Nucleic Acids Res. 43:D512-20

Horn et al. (2014) Nature Methods 11(6):603-4

Examples

Run this code
scores = KSEA.Scores(KSData, PX, NetworKIN=TRUE, NetworKIN.cutoff=3)
scores = KSEA.Scores(KSData, PX, NetworKIN=FALSE)

Run the code above in your browser using DataLab